complete -c gpg-tui -l config -d 'Sets the configuration file' -r
complete -c gpg-tui -l homedir -d 'Sets the GnuPG home directory' -r
complete -c gpg-tui -s o -l outdir -d 'Sets the output directory' -r
complete -c gpg-tui -l outfile -d 'Sets the template for the output file name' -r
complete -c gpg-tui -s d -l default-key -d 'Sets the default key to sign with' -r
complete -c gpg-tui -s t -l tick-rate -d 'Sets the tick rate of the terminal' -r
complete -c gpg-tui -s c -l color -d 'Sets the accent color of the terminal' -r
complete -c gpg-tui -s s -l style -d 'Sets the style of the terminal' -r -f -a "{plain	'Plain style with basic colors',colored	'More rich style with highlighted widgets and more colors'}"
complete -c gpg-tui -s f -l file-explorer -d 'Sets the utility for file selection' -r
complete -c gpg-tui -l detail-level -d 'Sets the detail level for the keys' -r -f -a "{minimum	'Show only the primary key and user ID',standard	'Show all subkeys and user IDs',full	'Show signatures'}"
complete -c gpg-tui -l select -d 'Enables the selection mode' -r -f -a "{row1	'One of the selected rows of the keys table',row2	'The other selected row of the keys table',key	'Exported key',key-id	'ID of the selected key',key-fingerprint	'Fingerprint of the selected key',user-id	'User ID of the selected key'}"
complete -c gpg-tui -s a -l armor -d 'Enables ASCII armored output'
complete -c gpg-tui -l splash -d 'Shows the splash screen on startup'
complete -c gpg-tui -s h -l help -d 'Print help (see more with \'--help\')'
complete -c gpg-tui -s V -l version -d 'Print version'
